from functools import wraps

from flask import redirect, request, session, url_for


def require_login(f):
    @wraps(f)
    def decorated_function(*args, **kwargs):
        if session.get("user") is None:
            return redirect(url_for("auth_view", next=request.url))
        return f(*args, **kwargs)

    return decorated_function



import apsw

DBNAME = "db.sqlite3"

_conn = None


def get_conn():
    global _conn
    if not _conn:
        _conn = apsw.Connection(DBNAME)
        # Apparently you need to enable this pragma _per connection_
        _conn.cursor().execute("PRAGMA foreign_keys = ON;")
    return _conn
